==> estateplat-common-1.2.4-20200115.012350-253-sources.jar: cn/gtmap/estateplat/model/information/core/XxXzwftd.java <==
package cn.gtmap.estateplat.model.information.core;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2019-12-17
 * @description 闲置违法土地模型
 */
@Table(name = "xx_xzwftd")
public class XxXzwftd extends XxMxParent implements InsertVo, XxMxVo {
    @Id
    private String ywid;//主键
    @Column
    private String proid;//项目表主键
    @Column
    private String yddw;//用地单位
    @Column
    private String ydwz;//用地位置
    @Column
    private String bz; //备注
    @Column
    private String xxgxqk;//信息共享情况

    @Override
    public String getProid() {
        return proid;
    }

    @Override
    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getYddw() {
        return yddw;
    }

    public void setYddw(String yddw) {
        this.yddw = yddw;
    }

    public String getYdwz() {
        return ydwz;
    }

    public void setYdwz(String ydwz) {
        this.ydwz = ydwz;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getXxgxqk() {
        return xxgxqk;
    }

    public void setXxgxqk(String xxgxqk) {
        this.xxgxqk = xxgxqk;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }


    @Override
    public void setDwmc(String dwmc) {
        super.dwmc = "XXXX";
    }

    @Override
    public void setDwbm(String dwbm) {
        super.dwbm = "XXXX";
    }

    @Override
    public void setMxlx(String mxlx) {
        super.mxlx = "xzwftd";
    }
}

==> estateplat-common-1.2.4-20201113.014416-502-sources.jar: cn/gtmap/estateplat/model/information/core/XxXzwftd.java <==
package cn.gtmap.estateplat.model.information.core;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2019-12-17
 * @description 闲置违法土地模型
 */
@Table(name = "xx_xzwftd")
public class XxXzwftd extends XxMxParent implements InsertVo, XxMxVo {
    @Id
    private String ywid;//主键
    @Column
    private String proid;//项目表主键
    @Column
    private String yddw;//用地单位
    @Column
    private String ydwz;//用地位置
    @Column
    private String bz; //备注
    @Column
    private String xxgxqk;//信息共享情况
    @Column
    private String tjzt;//提交状态

    public String getTjzt() {
        return tjzt;
    }

    public void setTjzt(String tjzt) {
        this.tjzt = tjzt;
    }

    @Override
    public String getProid() {
        return proid;
    }

    @Override
    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getYddw() {
        return yddw;
    }

    public void setYddw(String yddw) {
        this.yddw = yddw;
    }

    public String getYdwz() {
        return ydwz;
    }

    public void setYdwz(String ydwz) {
        this.ydwz = ydwz;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getXxgxqk() {
        return xxgxqk;
    }

    public void setXxgxqk(String xxgxqk) {
        this.xxgxqk = xxgxqk;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }


    @Override
    public void setDwmc(String dwmc) {
        super.dwmc = "XXXX";
    }

    @Override
    public void setDwbm(String dwbm) {
        super.dwbm = "XXXX";
    }

    @Override
    public void setMxlx(String mxlx) {
        super.mxlx = "xzwftd";
    }
}
